/*
 * Copyright 2024 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.material.icons.filled

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.materialIcon
import androidx.compose.material.icons.materialPath
import androidx.compose.ui.graphics.vector.ImageVector

public val Icons.Filled.SensorOccupied: ImageVector
    get() {
        if (_sensorOccupied != null) {
            return _sensorOccupied!!
        }
        _sensorOccupied = materialIcon(name = "Filled.SensorOccupied") {
            materialPath {
                moveTo(12.0f, 11.0f)
                curveToRelative(1.66f, 0.0f, 3.0f, -1.34f, 3.0f, -3.0f)
                reflectiveCurveToRelative(-1.34f, -3.0f, -3.0f, -3.0f)
                reflectiveCurveTo(9.0f, 6.34f, 9.0f, 8.0f)
                reflectiveCurveTo(10.34f, 11.0f, 12.0f, 11.0f)
                close()
            }
            materialPath {
                moveTo(12.0f, 12.0f)
                curveToRelative(-1.84f, 0.0f, -3.56f, 0.5f, -5.03f, 1.37f)
                curveTo(6.36f, 13.72f, 6.0f, 14.39f, 6.0f, 15.09f)
                verticalLineTo(17.0f)
                horizontalLineToRelative(12.0f)
                verticalLineToRelative(-1.91f)
                curveToRelative(0.0f, -0.7f, -0.36f, -1.36f, -0.97f, -1.72f)
                curveTo(15.56f, 12.5f, 13.84f, 12.0f, 12.0f, 12.0f)
                close()
            }
            materialPath {
                moveTo(21.23f, 8.15f)
                lineToRelative(1.85f, -0.77f)
                curveToRelative(-1.22f, -2.91f, -3.55f, -5.25f, -6.46f, -6.46f)
                lineToRelative(-0.77f, 1.85f)
                curveTo(18.27f, 3.79f, 20.21f, 5.73f, 21.23f, 8.15f)
                close()
            }
            materialPath {
                moveTo(8.15f, 2.77f)
                lineTo(7.38f, 0.92f)
                curveTo(4.47f, 2.14f, 2.14f, 4.47f, 0.92f, 7.38f)
                lineToRelative(1.85f, 0.77f)
                curveTo(3.79f, 5.73f, 5.73f, 3.79f, 8.15f, 2.77f)
                close()
            }
            materialPath {
                moveTo(2.77f, 15.85f)
                lineToRelative(-1.85f, 0.77f)
                curveToRelative(1.22f, 2.91f, 3.55f, 5.25f, 6.46f, 6.46f)
                lineToRelative(0.77f, -1.85f)
                curveTo(5.73f, 20.21f, 3.79f, 18.27f, 2.77f, 15.85f)
                close()
            }
            materialPath {
                moveTo(15.85f, 21.23f)
                lineToRelative(0.77f, 1.85f)
                curveToRelative(2.91f, -1.22f, 5.25f, -3.55f, 6.46f, -6.46f)
                lineToRelative(-1.85f, -0.77f)
                curveTo(20.21f, 18.27f, 18.27f, 20.21f, 15.85f, 21.23f)
                close()
            }
        }
        return _sensorOccupied!!
    }

private var _sensorOccupied: ImageVector? = null
